@@ -41,13 +41,17 @@ def createTable(dbName):
         
         
         sql = sql+lineName+lineType+"NOT NULL"+linePk
+        linePk = ", "
 
         if newLines == 2:
             break
     
+    print(sql)
+
 
     conn = sqlite3.connect(dbName)
     cursor = conn.cursor()
+
     cursor.execute(sql)
 
     conn.close()
